@@ -20,6 +20,7 @@
 Example Airflow DAG that uses Google AutoML services.
 """
 import os
+from datetime import datetime
 
 from airflow import models
 from airflow.providers.google.cloud.hooks.automl import CloudAutoMLHook
@@ -30,11 +31,12 @@ from airflow.providers.google.cloud.operators.automl import (
     AutoMLImportDataOperator,
     AutoMLTrainModelOperator,
 )
-from airflow.utils.dates import days_ago
 
 GCP_PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "your-project-id")
 GCP_AUTOML_LOCATION = os.environ.get("GCP_AUTOML_LOCATION", "us-central1")
-GCP_AUTOML_TEXT_BUCKET = os.environ.get("GCP_AUTOML_TEXT_BUCKET", "gs://cloud-ml-data/NL-entity/dataset.csv")
+GCP_AUTOML_TEXT_BUCKET = os.environ.get(
+    "GCP_AUTOML_TEXT_BUCKET", "gs://INVALID BUCKET NAME/NL-entity/dataset.csv"
+)
 
 # Example values
 DATASET_ID = ""
@@ -57,7 +59,8 @@ extract_object_id = CloudAutoMLHook.extract_object_id
 with models.DAG(
     "example_automl_text",
     schedule_interval=None,  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
     user_defined_macros={"extract_object_id": extract_object_id},
     tags=['example'],
 ) as example_dag:
@@ -65,7 +68,7 @@ with models.DAG(
         task_id="create_dataset_task", dataset=DATASET, location=GCP_AUTOML_LOCATION
     )
 
-    dataset_id = '{{ task_instance.xcom_pull("create_dataset_task", key="dataset_id") }}'
+    dataset_id = create_dataset_task.output['dataset_id']
 
     import_dataset_task = AutoMLImportDataOperator(
         task_id="import_dataset_task",
@@ -78,7 +81,7 @@ with models.DAG(
 
     create_model = AutoMLTrainModelOperator(task_id="create_model", model=MODEL, location=GCP_AUTOML_LOCATION)
 
-    model_id = "{{ task_instance.xcom_pull('create_model', key='model_id') }}"
+    model_id = create_model.output['model_id']
 
     delete_model_task = AutoMLDeleteModelOperator(
         task_id="delete_model_task",
@@ -94,4 +97,11 @@ with models.DAG(
         project_id=GCP_PROJECT_ID,
     )
 
-    create_dataset_task >> import_dataset_task >> create_model >> delete_model_task >> delete_datasets_task
+    import_dataset_task >> create_model
+    delete_model_task >> delete_datasets_task
+
+    # Task dependencies created via `XComArgs`:
+    #   create_dataset_task >> import_dataset_task
+    #   create_dataset_task >> create_model
+    #   create_model >> delete_model_task
+    #   create_dataset_task >> delete_datasets_task
