@@ -32,6 +32,7 @@ This DAG relies on the following OS environment variables
 """
 
 import os
+from datetime import datetime
 
 from airflow import models
 from airflow.operators.bash import BashOperator
@@ -54,7 +55,6 @@ from airflow.providers.google.cloud.operators.vision import (
     CloudVisionUpdateProductOperator,
     CloudVisionUpdateProductSetOperator,
 )
-from airflow.utils.dates import days_ago
 
 # [START howto_operator_vision_retry_import]
 from google.api_core.retry import Retry  # isort:skip
@@ -77,6 +77,7 @@ from google.cloud.vision import enums  # isort:skip
 
 # [END howto_operator_vision_enums_import]
 
+START_DATE = datetime(2021, 1, 1)
 
 GCP_VISION_LOCATION = os.environ.get('GCP_VISION_LOCATION', 'europe-west1')
 
@@ -114,7 +115,10 @@ DETECT_IMAGE = {"source": {"image_uri": GCP_VISION_ANNOTATE_IMAGE_URL}}
 # [END howto_operator_vision_detect_image_param]
 
 with models.DAG(
-    'example_gcp_vision_autogenerated_id', schedule_interval='@once', start_date=days_ago(1)
+    'example_gcp_vision_autogenerated_id',
+    schedule_interval='@once',
+    start_date=START_DATE,
+    catchup=False,
 ) as dag_autogenerated_id:
     # ################################## #
     # ### Autogenerated IDs examples ### #
@@ -269,7 +273,10 @@ with models.DAG(
 
 
 with models.DAG(
-    'example_gcp_vision_explicit_id', schedule_interval='@once', start_date=days_ago(1)
+    'example_gcp_vision_explicit_id',
+    schedule_interval='@once',
+    start_date=START_DATE,
+    catchup=False,
 ) as dag_explicit_id:
     # ############################# #
     # ### Explicit IDs examples ### #
@@ -434,7 +441,10 @@ with models.DAG(
     remove_product_from_product_set_2 >> product_delete_2
 
 with models.DAG(
-    'example_gcp_vision_annotate_image', schedule_interval='@once', start_date=days_ago(1)
+    'example_gcp_vision_annotate_image',
+    schedule_interval='@once',
+    start_date=START_DATE,
+    catchup=False,
 ) as dag_annotate_image:
     # ############################## #
     # ### Annotate image example ### #
