@@ -27,6 +27,7 @@ from google.cloud.bigtable.instance import Instance
 from google.cloud.bigtable.table import ClusterState, Table
 from google.cloud.bigtable_admin_v2 import enums
 
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 
@@ -38,7 +39,6 @@ class BigtableHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
-    # pylint: disable=too-many-arguments
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
@@ -57,7 +57,7 @@ class BigtableHook(GoogleBaseHook):
             self._client = Client(
                 project=project_id,
                 credentials=self._get_credentials(),
-                client_info=self.client_info,
+                client_info=CLIENT_INFO,
                 admin=True,
             )
         return self._client
@@ -69,11 +69,9 @@ class BigtableHook(GoogleBaseHook):
         Otherwise, returns None.
 
         :param instance_id: The ID of the Cloud Bigtable instance.
-        :type instance_id: str
         :param project_id: Optional, Google Cloud  project ID where the
             BigTable exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         """
         instance = self._get_client(project_id=project_id).instance(instance_id)
         if not instance.exists():
@@ -90,9 +88,7 @@ class BigtableHook(GoogleBaseHook):
         :param project_id: Optional, Google Cloud project ID where the
             BigTable exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param instance_id: The ID of the Cloud Bigtable instance.
-        :type instance_id: str
         """
         instance = self.get_instance(instance_id=instance_id, project_id=project_id)
         if instance:
@@ -122,39 +118,26 @@ class BigtableHook(GoogleBaseHook):
         """
         Creates new instance.
 
-        :type instance_id: str
         :param instance_id: The ID for the new instance.
-        :type main_cluster_id: str
         :param main_cluster_id: The ID for main cluster for the new instance.
-        :type main_cluster_zone: str
         :param main_cluster_zone: The zone for main cluster.
             See https://cloud.google.com/bigtable/docs/locations for more details.
-        :type project_id: str
         :param project_id: Optional, Google Cloud project ID where the
             BigTable exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type replica_clusters: List[Dict[str, str]]
         :param replica_clusters: (optional) A list of replica clusters for the new
             instance. Each cluster dictionary contains an id and a zone.
             Example: [{"id": "replica-1", "zone": "us-west1-a"}]
-        :type replica_cluster_id: str
         :param replica_cluster_id: (deprecated) The ID for replica cluster for the new
             instance.
-        :type replica_cluster_zone: str
         :param replica_cluster_zone: (deprecated)  The zone for replica cluster.
-        :type instance_type: enums.Instance.Type
         :param instance_type: (optional) The type of the instance.
-        :type instance_display_name: str
         :param instance_display_name: (optional) Human-readable name of the instance.
                 Defaults to ``instance_id``.
-        :type instance_labels: dict
         :param instance_labels: (optional) Dictionary of labels to associate with the
             instance.
-        :type cluster_nodes: int
         :param cluster_nodes: (optional) Number of nodes for cluster.
-        :type cluster_storage_type: enums.StorageType
         :param cluster_storage_type: (optional) The type of storage.
-        :type timeout: int
         :param timeout: (optional) timeout (in seconds) for instance creation.
                         If None is not specified, Operator will wait indefinitely.
         """
@@ -217,20 +200,14 @@ class BigtableHook(GoogleBaseHook):
         """
         Update an existing instance.
 
-        :type instance_id: str
         :param instance_id: The ID for the existing instance.
-        :type project_id: str
         :param project_id: Optional, Google Cloud project ID where the
             BigTable exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type instance_display_name: str
         :param instance_display_name: (optional) Human-readable name of the instance.
-        :type instance_type: enums.Instance.Type or enum.IntEnum
         :param instance_type: (optional) The type of the instance.
-        :type instance_labels: dict
         :param instance_labels: (optional) Dictionary of labels to associate with the
             instance.
-        :type timeout: int
         :param timeout: (optional) timeout (in seconds) for instance update.
             If None is not specified, Operator will wait indefinitely.
         """
@@ -260,14 +237,10 @@ class BigtableHook(GoogleBaseHook):
         Creates the specified Cloud Bigtable table.
         Raises ``google.api_core.exceptions.AlreadyExists`` if the table exists.
 
-        :type instance: Instance
         :param instance: The Cloud Bigtable instance that owns the table.
-        :type table_id: str
         :param table_id: The ID of the table to create in Cloud Bigtable.
-        :type initial_split_keys: list
         :param initial_split_keys: (Optional) A list of row keys in bytes to use to
             initially split the table.
-        :type column_families: dict
         :param column_families: (Optional) A map of columns to create. The key is the
             column_id str, and the value is a
             :class:`google.cloud.bigtable.column_family.GarbageCollectionRule`.
@@ -285,11 +258,8 @@ class BigtableHook(GoogleBaseHook):
         Deletes the specified table in Cloud Bigtable.
         Raises google.api_core.exceptions.NotFound if the table does not exist.
 
-        :type instance_id: str
         :param instance_id: The ID of the Cloud Bigtable instance.
-        :type table_id: str
         :param table_id: The ID of the table in Cloud Bigtable.
-        :type project_id: str
         :param project_id: Optional, Google Cloud project ID where the
             BigTable exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
@@ -303,11 +273,8 @@ class BigtableHook(GoogleBaseHook):
         Updates number of nodes in the specified Cloud Bigtable cluster.
         Raises google.api_core.exceptions.NotFound if the cluster does not exist.
 
-        :type instance: Instance
         :param instance: The Cloud Bigtable instance that owns the cluster.
-        :type cluster_id: str
         :param cluster_id: The ID of the cluster.
-        :type nodes: int
         :param nodes: The desired number of nodes.
         """
         cluster = Cluster(cluster_id, instance)
@@ -319,9 +286,7 @@ class BigtableHook(GoogleBaseHook):
         """
         Fetches Column Families for the specified table in Cloud Bigtable.
 
-        :type instance: Instance
         :param instance: The Cloud Bigtable instance that owns the table.
-        :type table_id: str
         :param table_id: The ID of the table in Cloud Bigtable to fetch Column Families
             from.
         """
@@ -334,9 +299,7 @@ class BigtableHook(GoogleBaseHook):
         Fetches Cluster States for the specified table in Cloud Bigtable.
         Raises google.api_core.exceptions.NotFound if the table does not exist.
 
-        :type instance: Instance
         :param instance: The Cloud Bigtable instance that owns the table.
-        :type table_id: str
         :param table_id: The ID of the table in Cloud Bigtable to fetch Cluster States
             from.
         """
