@@ -79,13 +79,10 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param zone: Google Cloud zone where the instance exists
-        :type zone: str
         :param resource_id: Name of the Compute Engine instance resource
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         response = (
@@ -107,13 +104,10 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param zone: Google Cloud zone where the instance exists
-        :type zone: str
         :param resource_id: Name of the Compute Engine instance resource
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         response = (
@@ -135,17 +129,13 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param zone: Google Cloud zone where the instance exists.
-        :type zone: str
         :param resource_id: Name of the Compute Engine instance resource
-        :type resource_id: str
         :param body: Body required by the Compute Engine setMachineType API,
             as described in
             https://cloud.google.com/compute/docs/reference/rest/v1/instances/setMachineType
-        :type body: dict
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         response = self._execute_set_machine_type(zone, resource_id, body, project_id)
@@ -171,11 +161,9 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param resource_id: Name of the instance template
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: Instance template representation as object according to
             https://cloud.google.com/compute/docs/reference/rest/v1/instanceTemplates
         :rtype: dict
@@ -201,16 +189,13 @@ class ComputeEngineHook(GoogleBaseHook):
 
         :param body: Instance template representation as object according to
             https://cloud.google.com/compute/docs/reference/rest/v1/instanceTemplates
-        :type body: dict
         :param request_id: Optional, unique request_id that you might add to achieve
             full idempotence (for example when client call times out repeating the request
             with the same request id will not create a new instance template again)
             It should be in UUID format as defined in RFC 4122
-        :type request_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         response = (
@@ -237,13 +222,10 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param zone: Google Cloud zone where the Instance Group Manager exists
-        :type zone: str
         :param resource_id: Name of the Instance Group Manager
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: Instance group manager representation as object according to
             https://cloud.google.com/compute/docs/reference/rest/beta/instanceGroupManagers
         :rtype: dict
@@ -270,22 +252,17 @@ class ComputeEngineHook(GoogleBaseHook):
         Must be called with keyword arguments rather than positional.
 
         :param zone: Google Cloud zone where the Instance Group Manager exists
-        :type zone: str
         :param resource_id: Name of the Instance Group Manager
-        :type resource_id: str
         :param body: Instance Group Manager representation as json-merge-patch object
             according to
             https://cloud.google.com/compute/docs/reference/rest/beta/instanceTemplates/patch
-        :type body: dict
         :param request_id: Optional, unique request_id that you might add to achieve
             full idempotence (for example when client call times out repeating the request
             with the same request id will not create a new instance template again).
             It should be in UUID format as defined in RFC 4122
-        :type request_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         response = (
@@ -313,9 +290,7 @@ class ComputeEngineHook(GoogleBaseHook):
         Waits for the named operation to complete - checks status of the async call.
 
         :param operation_name: name of the operation
-        :type operation_name: str
         :param zone: optional region of the request (might be None for global operations)
-        :type zone: str
         :return: None
         """
         service = self.get_conn()
@@ -368,13 +343,10 @@ class ComputeEngineHook(GoogleBaseHook):
         Gets instance information.
 
         :param zone: Google Cloud zone where the Instance Group Manager exists
-        :type zone: str
         :param resource_id: Name of the Instance Group Manager
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         """
         instance_info = (
             self.get_conn()
@@ -392,15 +364,11 @@ class ComputeEngineHook(GoogleBaseHook):
         Return network address associated to instance.
 
         :param zone: Google Cloud zone where the Instance Group Manager exists
-        :type zone: str
         :param resource_id: Name of the Instance Group Manager
-        :type resource_id: str
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param use_internal_ip: If true, return private IP address.
-        :type use_internal_ip: bool
         """
         instance_info = self.get_instance_info(project_id=project_id, resource_id=resource_id, zone=zone)
         if use_internal_ip:
@@ -419,15 +387,11 @@ class ComputeEngineHook(GoogleBaseHook):
         Set instance metadata.
 
         :param zone: Google Cloud zone where the Instance Group Manager exists
-        :type zone: str
         :param resource_id: Name of the Instance Group Manager
-        :type resource_id: str
         :param metadata: The new instance metadata.
-        :type metadata: Dict
         :param project_id: Optional, Google Cloud project ID where the
             Compute Engine Instance exists. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         """
         response = (
             self.get_conn()
