@@ -28,6 +28,7 @@ from google.cloud.metastore_v1.types.metastore import DatabaseDumpSpec, Restore
 from google.protobuf.field_mask_pb2 import FieldMask
 
 from airflow.exceptions import AirflowException
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 
@@ -39,7 +40,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         client_options = {'api_endpoint': 'metastore.googleapis.com:443'}
 
         return DataprocMetastoreClient(
-            credentials=self._get_credentials(), client_info=self.client_info, client_options=client_options
+            credentials=self._get_credentials(), client_info=CLIENT_INFO, client_options=client_options
         )
 
     def wait_for_operation(self, timeout: Optional[float], operation: Operation):
@@ -67,9 +68,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Creates a new backup in a given project and location.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -77,28 +76,21 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param backup:  Required. The backup to create. The ``name`` field is ignored. The ID of the created
             backup must be provided in the request's ``backup_id`` field.
 
             This corresponds to the ``backup`` field on the ``request`` instance; if ``request`` is provided,
             this should not be set.
-        :type backup: google.cloud.metastore_v1.types.Backup
         :param backup_id:  Required. The ID of the backup, which is used as the final component of the
             backup's name. This value must be between 1 and 64 characters long, begin with a letter, end with
             a letter or number, and consist of alphanumeric ASCII characters or hyphens.
 
             This corresponds to the ``backup_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type backup_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         parent = f'projects/{project_id}/locations/{region}/services/{service_id}'
 
@@ -133,9 +125,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Creates a new MetadataImport in a given project and location.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -143,13 +133,11 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param metadata_import:  Required. The metadata import to create. The ``name`` field is ignored. The
             ID of the created metadata import must be provided in the request's ``metadata_import_id`` field.
 
             This corresponds to the ``metadata_import`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type metadata_import: google.cloud.metastore_v1.types.MetadataImport
         :param metadata_import_id:  Required. The ID of the metadata import, which is used as the final
             component of the metadata import's name. This value must be between 1 and 64 characters long,
             begin with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -157,15 +145,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``metadata_import_id`` field on the ``request`` instance; if ``request``
             is provided, this should not be set.
-        :type metadata_import_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         parent = f'projects/{project_id}/locations/{region}/services/{service_id}'
 
@@ -199,15 +182,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Creates a metastore service in a project and location.
 
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param service:  Required. The Metastore service to create. The ``name`` field is ignored. The ID of
             the created metastore service must be provided in the request's ``service_id`` field.
 
             This corresponds to the ``service`` field on the ``request`` instance; if ``request`` is provided,
             this should not be set.
-        :type service: google.cloud.metastore_v1.types.Service
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -215,15 +195,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         parent = f'projects/{project_id}/locations/{region}'
 
@@ -257,9 +232,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Deletes a single backup.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -267,22 +240,16 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param backup_id:  Required. The ID of the backup, which is used as the final component of the
             backup's name. This value must be between 1 and 64 characters long, begin with a letter, end with
             a letter or number, and consist of alphanumeric ASCII characters or hyphens.
 
             This corresponds to the ``backup_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type backup_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         name = f'projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}'
 
@@ -313,9 +280,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Deletes a single service.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -323,15 +288,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         name = f'projects/{project_id}/locations/{region}/services/{service_id}'
 
@@ -367,11 +327,8 @@ class DataprocMetastoreHook(GoogleBaseHook):
             ``gs://<bucket_name>/<path_inside_bucket>``. A sub-folder
             ``<export_folder>`` containing exported files will be
             created below it.
-        :type destination_gcs_folder: str
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -379,18 +336,12 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param database_dump_type: Optional. The type of the database dump. If unspecified,
             defaults to ``MYSQL``.
-        :type database_dump_type: google.cloud.metastore_v1.types.DatabaseDumpSpec.Type
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         service = f'projects/{project_id}/locations/{region}/services/{service_id}'
 
@@ -422,9 +373,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Gets the details of a single service.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -432,13 +381,9 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         name = f'projects/{project_id}/locations/{region}/services/{service_id}'
 
@@ -468,9 +413,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Get backup from a service.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -478,15 +421,10 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param backup_id:  Required. The ID of the metastore service backup to restore from
-        :type backup_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         backup = f'projects/{project_id}/locations/{region}/services/{service_id}/backups/{backup_id}'
         client = self.get_dataproc_metastore_client()
@@ -518,9 +456,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Lists backups in a service.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -528,13 +464,11 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param page_size: Optional. The maximum number of backups to
             return. The response may contain less than the
             maximum number. If unspecified, no more than 500
             backups are returned. The maximum value is 1000;
             values above 1000 are changed to 1000.
-        :type page_size: int
         :param page_token: Optional. A page token, received from a previous
             [DataprocMetastore.ListBackups][google.cloud.metastore.v1.DataprocMetastore.ListBackups]
             call. Provide this token to retrieve the subsequent page.
@@ -542,22 +476,16 @@ class DataprocMetastoreHook(GoogleBaseHook):
             When paginating, other parameters provided to
             [DataprocMetastore.ListBackups][google.cloud.metastore.v1.DataprocMetastore.ListBackups]
             must match the call that provided the page token.
-        :type page_token: str
         :param filter: Optional. The filter to apply to list
             results.
-        :type filter: str
         :param order_by: Optional. Specify the ordering of results as described in
             `Sorting
             Order <https://cloud.google.com/apis/design/design_patterns#sorting_order>`__.
             If not specified, the results will be sorted in the default
             order.
-        :type order_by: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         parent = f'projects/{project_id}/locations/{region}/services/{service_id}/backups'
 
@@ -596,9 +524,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Restores a service from a backup.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -606,31 +532,21 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param backup_project_id: Required. The ID of the Google Cloud project that the metastore service
             backup to restore from.
-        :type backup_project_id: str
         :param backup_region: Required. The ID of the Google Cloud region that the metastore
             service backup to restore from.
-        :type backup_region: str
         :param backup_service_id:  Required. The ID of the metastore service backup to restore from,
             which is used as the final component of the metastore service's name. This value must be
             between 2 and 63 characters long inclusive, begin with a letter, end with a letter or number,
             and consist of alphanumeric ASCII characters or hyphens.
-        :type backup_service_id: str
         :param backup_id:  Required. The ID of the metastore service backup to restore from
-        :type backup_id: str
         :param restore_type: Optional. The type of restore. If unspecified, defaults to
             ``METADATA_ONLY``
-        :type restore_type: google.cloud.metastore_v1.types.Restore.RestoreType
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         service = f'projects/{project_id}/locations/{region}/services/{service_id}'
         backup = (
@@ -669,9 +585,7 @@ class DataprocMetastoreHook(GoogleBaseHook):
         Updates the parameters of a single service.
 
         :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
-        :type project_id: str
         :param region: Required. The ID of the Google Cloud region that the service belongs to.
-        :type region: str
         :param service_id:  Required. The ID of the metastore service, which is used as the final component of
             the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
             with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
@@ -679,7 +593,6 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service_id`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type service_id: str
         :param service:  Required. The metastore service to update. The server only merges fields in the
             service if they are specified in ``update_mask``.
 
@@ -687,22 +600,16 @@ class DataprocMetastoreHook(GoogleBaseHook):
 
             This corresponds to the ``service`` field on the ``request`` instance; if ``request`` is provided,
             this should not be set.
-        :type service: Union[Dict, google.cloud.metastore_v1.types.Service]
         :param update_mask:  Required. A field mask used to specify the fields to be overwritten in the
             metastore service resource by the update. Fields specified in the ``update_mask`` are relative to
             the resource (not to the full request). A field is overwritten if it is in the mask.
 
             This corresponds to the ``update_mask`` field on the ``request`` instance; if ``request`` is
             provided, this should not be set.
-        :type update_mask: google.protobuf.field_mask_pb2.FieldMask
         :param request_id: Optional. A unique id used to identify the request.
-        :type request_id: str
         :param retry: Designation of what errors, if any, should be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The timeout for this request.
-        :type timeout: float
         :param metadata: Strings which should be sent along with the request as metadata.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_dataproc_metastore_client()
 
