@@ -36,7 +36,6 @@ class DatastoreHook(GoogleBaseHook):
     simultaneously, you will need to create a hook per thread.
 
     :param api_version: The version of the API it is going to connect to.
-    :type api_version: str
     """
 
     def __init__(
@@ -87,9 +86,7 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/allocateIds
 
         :param partial_keys: a list of partial keys.
-        :type partial_keys: list
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: a list of full keys.
         :rtype: list
         """
@@ -112,9 +109,7 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/beginTransaction
 
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :param transaction_options: Options for a new transaction.
-        :type transaction_options: Dict[str, Any]
         :return: a transaction handle.
         :rtype: str
         """
@@ -137,9 +132,7 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/commit
 
         :param body: the body of the commit request.
-        :type body: dict
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: the response body of the commit request.
         :rtype: dict
         """
@@ -164,14 +157,10 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/lookup
 
         :param keys: the keys to lookup.
-        :type keys: list
         :param read_consistency: the read consistency to use. default, strong or eventual.
                                  Cannot be used with a transaction.
-        :type read_consistency: str
         :param transaction: the transaction to use, if any.
-        :type transaction: str
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: the response body of the lookup request.
         :rtype: dict
         """
@@ -195,9 +184,7 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/rollback
 
         :param transaction: the transaction to roll back.
-        :type transaction: str
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         """
         conn: Any = self.get_conn()
 
@@ -214,9 +201,7 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/rest/v1/projects/runQuery
 
         :param body: the body of the query request.
-        :type body: dict
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: the batch of query results.
         :rtype: dict
         """
@@ -234,7 +219,6 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/get
 
         :param name: the name of the operation resource.
-        :type name: str
         :return: a resource operation instance.
         :rtype: dict
         """
@@ -252,7 +236,6 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/delete
 
         :param name: the name of the operation resource.
-        :type name: str
         :return: none if successful.
         :rtype: dict
         """
@@ -267,9 +250,7 @@ class DatastoreHook(GoogleBaseHook):
         Poll backup operation state until it's completed.
 
         :param name: the name of the operation resource
-        :type name: str
         :param polling_interval_in_seconds: The number of seconds to wait before calling another request.
-        :type polling_interval_in_seconds: float
         :return: a resource operation instance.
         :rtype: dict
         """
@@ -304,15 +285,10 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/admin/rest/v1/projects/export
 
         :param bucket: The name of the Cloud Storage bucket.
-        :type bucket: str
         :param namespace: The Cloud Storage namespace path.
-        :type namespace: str
         :param entity_filter: Description of what data from the project is included in the export.
-        :type entity_filter: dict
         :param labels: Client-assigned labels.
-        :type labels: dict of str
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: a resource operation instance.
         :rtype: dict
         """
@@ -356,17 +332,11 @@ class DatastoreHook(GoogleBaseHook):
             https://cloud.google.com/datastore/docs/reference/admin/rest/v1/projects/import
 
         :param bucket: The name of the Cloud Storage bucket.
-        :type bucket: str
         :param file: the metadata file written by the projects.export operation.
-        :type file: str
         :param namespace: The Cloud Storage namespace path.
-        :type namespace: str
         :param entity_filter: specify which kinds/namespaces are to be imported.
-        :type entity_filter: dict
         :param labels: Client-assigned labels.
-        :type labels: dict of str
         :param project_id: Google Cloud project ID against which to make the request.
-        :type project_id: str
         :return: a resource operation instance.
         :rtype: dict
         """
