@@ -31,6 +31,7 @@ from google.cloud.language_v1.types import (
     Document,
 )
 
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 
@@ -39,11 +40,9 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
     Hook for Google Cloud Natural Language Service.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -52,7 +51,6 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account.
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     def __init__(
@@ -76,9 +74,7 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
         :rtype: google.cloud.language_v1.LanguageServiceClient
         """
         if not self._conn:
-            self._conn = LanguageServiceClient(
-                credentials=self._get_credentials(), client_info=self.client_info
-            )
+            self._conn = LanguageServiceClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
         return self._conn
 
     @GoogleBaseHook.quota_retry()
@@ -96,17 +92,12 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param encoding_type: The encoding type used by the API to calculate offsets.
-        :type encoding_type: google.cloud.language_v1.enums.EncodingType
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.AnalyzeEntitiesResponse
         """
         client = self.get_conn()
@@ -130,17 +121,12 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param encoding_type: The encoding type used by the API to calculate offsets.
-        :type encoding_type: google.cloud.language_v1.enums.EncodingType
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.AnalyzeEntitiesResponse
         """
         client = self.get_conn()
@@ -163,17 +149,12 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param encoding_type: The encoding type used by the API to calculate offsets.
-        :type encoding_type: google.cloud.language_v1.enums.EncodingType
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.AnalyzeSentimentResponse
         """
         client = self.get_conn()
@@ -197,17 +178,12 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param encoding_type: The encoding type used by the API to calculate offsets.
-        :type encoding_type: google.cloud.language_v1.enums.EncodingType
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.AnalyzeSyntaxResponse
         """
         client = self.get_conn()
@@ -232,20 +208,14 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param features: The enabled features.
             If a dict is provided, it must be of the same form as the protobuf message Features
-        :type features: dict or google.cloud.language_v1.types.AnnotateTextRequest.Features
         :param encoding_type: The encoding type used by the API to calculate offsets.
-        :type encoding_type: google.cloud.language_v1.enums.EncodingType
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.AnnotateTextResponse
         """
         client = self.get_conn()
@@ -272,15 +242,11 @@ class CloudNaturalLanguageHook(GoogleBaseHook):
 
         :param document: Input document.
             If a dict is provided, it must be of the same form as the protobuf message Document
-        :type document: dict or google.cloud.language_v1.types.Document
         :param retry: A retry object used to retry requests. If None is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: sequence[tuple[str, str]]]
         :rtype: google.cloud.language_v1.types.ClassifyTextResponse
         """
         client = self.get_conn()
