@@ -14,12 +14,20 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+"""
+.. spelling::
+
+    ImportSshPublicKeyResponse
+    oslogin
+"""
+
 
 from typing import Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core.retry import Retry
 from google.cloud.oslogin_v1 import ImportSshPublicKeyResponse, OsLoginServiceClient
 
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 
@@ -49,7 +57,7 @@ class OSLoginHook(GoogleBaseHook):
         if self._conn:
             return self._conn
 
-        self._conn = OsLoginServiceClient(credentials=self._get_credentials(), client_info=self.client_info)
+        self._conn = OsLoginServiceClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
         return self._conn
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -68,19 +76,13 @@ class OSLoginHook(GoogleBaseHook):
         login profile.
 
         :param user: The unique ID for the user
-        :type user: str
         :param ssh_public_key: The SSH public key and expiration time.
-        :type ssh_public_key: dict
         :param project_id: The project ID of the Google Cloud project.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will
             be retried using a default configuration.
-        :type retry: Optional[google.api_core.retry.Retry]
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that
             if ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: Optional[float]
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         :return: A :class:`~google.cloud.oslogin_v1.ImportSshPublicKeyResponse` instance.
         """
         conn = self.get_conn()
