@@ -22,6 +22,7 @@ from google.api_core.retry import Retry
 from google.cloud.speech_v1 import SpeechClient
 from google.cloud.speech_v1.types import RecognitionAudio, RecognitionConfig
 
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 
@@ -30,11 +31,9 @@ class CloudSpeechToTextHook(GoogleBaseHook):
     Hook for Google Cloud Speech API.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -43,7 +42,6 @@ class CloudSpeechToTextHook(GoogleBaseHook):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account.
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     def __init__(
@@ -67,7 +65,7 @@ class CloudSpeechToTextHook(GoogleBaseHook):
         :rtype: google.cloud.speech_v1.SpeechClient
         """
         if not self._client:
-            self._client = SpeechClient(credentials=self._get_credentials(), client_info=self.client_info)
+            self._client = SpeechClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @GoogleBaseHook.quota_retry()
@@ -83,16 +81,12 @@ class CloudSpeechToTextHook(GoogleBaseHook):
 
         :param config: information to the recognizer that specifies how to process the request.
             https://googleapis.github.io/google-cloud-python/latest/speech/gapic/v1/types.html#google.cloud.speech_v1.types.RecognitionConfig
-        :type config: dict or google.cloud.speech_v1.types.RecognitionConfig
         :param audio: audio data to be recognized
             https://googleapis.github.io/google-cloud-python/latest/speech/gapic/v1/types.html#google.cloud.speech_v1.types.RecognitionAudio
-        :type audio: dict or google.cloud.speech_v1.types.RecognitionAudio
         :param retry: (Optional) A retry object used to retry requests. If None is specified,
             requests will not be retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: (Optional) The amount of time, in seconds, to wait for the request to complete.
             Note that if retry is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         """
         client = self.get_conn()
         response = client.recognize(config=config, audio=audio, retry=retry, timeout=timeout)
