@@ -49,22 +49,15 @@ class AutoMLTrainModelOperator(BaseOperator):
         :ref:`howto/operator:AutoMLTrainModelOperator`
 
     :param model: Model definition.
-    :type model: dict
     :param project_id: ID of the Google Cloud project where model will be created if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -73,7 +66,6 @@ class AutoMLTrainModelOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -138,26 +130,17 @@ class AutoMLPredictOperator(BaseOperator):
         :ref:`howto/operator:AutoMLPredictOperator`
 
     :param model_id: Name of the model requested to serve the batch prediction.
-    :type model_id: str
     :param payload: Name od the model used for the prediction.
-    :type payload: dict
     :param project_id: ID of the Google Cloud project where model is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param operation_params: Additional domain-specific parameters for the predictions.
-    :type operation_params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -166,7 +149,6 @@ class AutoMLPredictOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -232,37 +214,25 @@ class AutoMLBatchPredictOperator(BaseOperator):
 
     :param project_id: ID of the Google Cloud project where model will be created if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param model_id: Name of the model_id requested to serve the batch prediction.
-    :type model_id: str
     :param input_config: Required. The input configuration for batch prediction.
         If a dict is provided, it must be of the same form as the protobuf message
         `google.cloud.automl_v1beta1.types.BatchPredictInputConfig`
-    :type input_config: Union[dict, ~google.cloud.automl_v1beta1.types.BatchPredictInputConfig]
     :param output_config: Required. The Configuration specifying where output predictions should be
         written. If a dict is provided, it must be of the same form as the protobuf message
         `google.cloud.automl_v1beta1.types.BatchPredictOutputConfig`
-    :type output_config: Union[dict, ~google.cloud.automl_v1beta1.types.BatchPredictOutputConfig]
     :param prediction_params: Additional domain-specific parameters for the predictions,
         any string must be up to 25000 characters long.
-    :type prediction_params: Optional[Dict[str, str]]
     :param project_id: ID of the Google Cloud project where model is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -271,7 +241,6 @@ class AutoMLBatchPredictOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -345,24 +314,16 @@ class AutoMLCreateDatasetOperator(BaseOperator):
 
     :param dataset: The dataset to create. If a dict is provided, it must be of the
         same form as the protobuf message Dataset.
-    :type dataset: Union[dict, Dataset]
     :param project_id: ID of the Google Cloud project where dataset is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -371,7 +332,6 @@ class AutoMLCreateDatasetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -436,27 +396,18 @@ class AutoMLImportDataOperator(BaseOperator):
         :ref:`howto/operator:AutoMLImportDataOperator`
 
     :param dataset_id: ID of dataset to be updated.
-    :type dataset_id: str
     :param input_config: The desired input location and its domain specific semantics, if any.
         If a dict is provided, it must be of the same form as the protobuf message InputConfig.
-    :type input_config: dict
     :param project_id: ID of the Google Cloud project where dataset is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -465,7 +416,6 @@ class AutoMLImportDataOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -530,35 +480,24 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         :ref:`howto/operator:AutoMLTablesListColumnSpecsOperator`
 
     :param dataset_id: Name of the dataset.
-    :type dataset_id: str
     :param table_spec_id: table_spec_id for path builder.
-    :type table_spec_id: str
     :param field_mask: Mask specifying which fields to read. If a dict is provided, it must be of the same
         form as the protobuf message `google.cloud.automl_v1beta1.types.FieldMask`
-    :type field_mask: Union[dict, google.cloud.automl_v1beta1.types.FieldMask]
     :param filter_: Filter expression, see go/filtering.
-    :type filter_: str
     :param page_size: The maximum number of resources contained in the
         underlying API response. If page streaming is performed per
         resource, this parameter does not affect the return value. If page
         streaming is performed per page, this determines the maximum number
         of resources in a page.
-    :type page_size: int
     :param project_id: ID of the Google Cloud project where dataset is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -567,7 +506,6 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -645,24 +583,16 @@ class AutoMLTablesUpdateDatasetOperator(BaseOperator):
 
     :param dataset: The dataset which replaces the resource on the server.
         If a dict is provided, it must be of the same form as the protobuf message Dataset.
-    :type dataset: Union[dict, Dataset]
     :param update_mask: The update mask applies to the resource.  If a dict is provided, it must
         be of the same form as the protobuf message FieldMask.
-    :type update_mask: Union[dict, FieldMask]
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -671,7 +601,6 @@ class AutoMLTablesUpdateDatasetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -731,24 +660,16 @@ class AutoMLGetModelOperator(BaseOperator):
         :ref:`howto/operator:AutoMLGetModelOperator`
 
     :param model_id: Name of the model requested to serve the prediction.
-    :type model_id: str
     :param project_id: ID of the Google Cloud project where model is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -757,7 +678,6 @@ class AutoMLGetModelOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -816,24 +736,16 @@ class AutoMLDeleteModelOperator(BaseOperator):
         :ref:`howto/operator:AutoMLDeleteModelOperator`
 
     :param model_id: Name of the model requested to serve the prediction.
-    :type model_id: str
     :param project_id: ID of the Google Cloud project where model is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -842,7 +754,6 @@ class AutoMLDeleteModelOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -906,28 +817,19 @@ class AutoMLDeployModelOperator(BaseOperator):
         :ref:`howto/operator:AutoMLDeployModelOperator`
 
     :param model_id: Name of the model to be deployed.
-    :type model_id: str
     :param image_detection_metadata: Model deployment metadata specific to Image Object Detection.
         If a dict is provided, it must be of the same form as the protobuf message
         ImageObjectDetectionModelDeploymentMetadata
-    :type image_detection_metadata: dict
     :param project_id: ID of the Google Cloud project where model is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param params: Additional domain-specific parameters for the predictions.
-    :type params: Optional[Dict[str, str]]
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -936,7 +838,6 @@ class AutoMLDeployModelOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1001,30 +902,21 @@ class AutoMLTablesListTableSpecsOperator(BaseOperator):
         :ref:`howto/operator:AutoMLTablesListTableSpecsOperator`
 
     :param dataset_id: Name of the dataset.
-    :type dataset_id: str
     :param filter_: Filter expression, see go/filtering.
-    :type filter_: str
     :param page_size: The maximum number of resources contained in the
         underlying API response. If page streaming is performed per
         resource, this parameter does not affect the return value. If page
         streaming is performed per-page, this determines the maximum number
         of resources in a page.
-    :type page_size: int
     :param project_id: ID of the Google Cloud project if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1033,7 +925,6 @@ class AutoMLTablesListTableSpecsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1103,19 +994,13 @@ class AutoMLListDatasetOperator(BaseOperator):
 
     :param project_id: ID of the Google Cloud project where datasets are located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1124,7 +1009,6 @@ class AutoMLListDatasetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1188,22 +1072,15 @@ class AutoMLDeleteDatasetOperator(BaseOperator):
 
     :param dataset_id: Name of the dataset_id, list of dataset_id or string of dataset_id
         coma separated to be deleted.
-    :type dataset_id: Union[str, List[str]]
     :param project_id: ID of the Google Cloud project where dataset is located if None then
         default project_id is used.
-    :type project_id: str
     :param location: The location of the project.
-    :type location: str
     :param retry: A retry object used to retry requests. If `None` is specified, requests will not be
         retried.
-    :type retry: Optional[google.api_core.retry.Retry]
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         `retry` is specified, the timeout applies to each individual attempt.
-    :type timeout: Optional[float]
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Optional[Sequence[Tuple[str, str]]]
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1212,7 +1089,6 @@ class AutoMLDeleteDatasetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
