@@ -56,42 +56,28 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableCreateInstanceOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance to create.
-    :type main_cluster_id: str
     :param main_cluster_id: The ID for main cluster for the new instance.
-    :type main_cluster_zone: str
     :param main_cluster_zone: The zone for main cluster
         See https://cloud.google.com/bigtable/docs/locations for more details.
-    :type project_id: str
     :param project_id: Optional, the ID of the Google Cloud project.  If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-    :type replica_clusters: List[Dict[str, str]]
     :param replica_clusters: (optional) A list of replica clusters for the new
         instance. Each cluster dictionary contains an id and a zone.
         Example: [{"id": "replica-1", "zone": "us-west1-a"}]
-    :type replica_cluster_id: str
     :param replica_cluster_id: (deprecated) The ID for replica cluster for the new
         instance.
-    :type replica_cluster_zone: str
     :param replica_cluster_zone: (deprecated)  The zone for replica cluster.
-    :type instance_type: enum.IntEnum
     :param instance_type: (optional) The type of the instance.
-    :type instance_display_name: str
     :param instance_display_name: (optional) Human-readable name of the instance. Defaults
         to ``instance_id``.
-    :type instance_labels: dict
     :param instance_labels: (optional) Dictionary of labels to associate
         with the instance.
-    :type cluster_nodes: int
     :param cluster_nodes: (optional) Number of nodes for cluster.
-    :type cluster_storage_type: enum.IntEnum
     :param cluster_storage_type: (optional) The type of storage.
-    :type timeout: int
     :param timeout: (optional) timeout (in seconds) for instance creation.
                     If None is not specified, Operator will wait indefinitely.
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -100,7 +86,6 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES: Iterable[str] = ('instance_id', 'main_cluster_id', 'main_cluster_zone')
@@ -196,23 +181,16 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableUpdateInstanceOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance to update.
-    :type project_id: str
     :param project_id: Optional, the ID of the Google Cloud project. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-    :type instance_display_name: str
     :param instance_display_name: (optional) Human-readable name of the instance.
-    :type instance_type: enums.Instance.Type or enum.IntEnum
     :param instance_type: (optional) The type of the instance.
-    :type instance_labels: dict
     :param instance_labels: (optional) Dictionary of labels to associate
         with the instance.
-    :type timeout: int
     :param timeout: (optional) timeout (in seconds) for instance update.
                     If None is not specified, Operator will wait indefinitely.
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -221,7 +199,6 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES: Iterable[str] = ['instance_id']
@@ -289,13 +266,10 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableDeleteInstanceOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance to delete.
     :param project_id: Optional, the ID of the Google Cloud project.  If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -304,7 +278,6 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id',)  # type: Iterable[str]
@@ -359,23 +332,17 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableCreateTableOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance that will
         hold the new table.
-    :type table_id: str
     :param table_id: The ID of the table to be created.
-    :type project_id: str
     :param project_id: Optional, the ID of the Google Cloud project. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-    :type initial_split_keys: list
     :param initial_split_keys: (Optional) list of row keys in bytes that will be used to
         initially split the table into several tablets.
-    :type column_families: dict
     :param column_families: (Optional) A map columns to create.
                             The key is the column_id str and the value is a
                             :class:`google.cloud.bigtable.column_family.GarbageCollectionRule`
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -384,7 +351,6 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
@@ -474,17 +440,12 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableDeleteTableOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance.
-    :type table_id: str
     :param table_id: The ID of the table to be deleted.
-    :type project_id: str
     :param project_id: Optional, the ID of the Google Cloud project. If set to None or missing,
             the default project_id from the Google Cloud connection is used.
-    :type app_profile_id: str
     :param app_profile_id: Application profile.
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -493,7 +454,6 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
@@ -559,16 +519,11 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:BigtableUpdateClusterOperator`
 
-    :type instance_id: str
     :param instance_id: The ID of the Cloud Bigtable instance.
-    :type cluster_id: str
     :param cluster_id: The ID of the Cloud Bigtable cluster to update.
-    :type nodes: int
     :param nodes: The desired number of nodes for the Cloud Bigtable cluster.
-    :type project_id: str
     :param project_id: Optional, the ID of the Google Cloud project.
     :param gcp_conn_id: The connection ID to use to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -577,7 +532,6 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'cluster_id', 'nodes')  # type: Iterable[str]
