@@ -15,7 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Operators for Google Cloud Memorystore service"""
+"""
+Operators for Google Cloud Memorystore service.
+
+.. spelling::
+
+    FieldMask
+    memcache
+"""
 from typing import TYPE_CHECKING, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core.retry import Retry
@@ -45,7 +52,6 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreCreateInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: Required. The logical name of the Redis instance in the customer project with the
         following restrictions:
 
@@ -54,25 +60,18 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         -  Must be between 1-40 characters.
         -  Must end with a number or a letter.
         -  Must be unique within the customer project / location
-    :type instance_id: str
     :param instance: Required. A Redis [Instance] resource
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.Instance`
-    :type instance: Union[Dict, google.cloud.redis_v1.types.Instance]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -81,7 +80,6 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -146,22 +144,15 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreDeleteInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -170,7 +161,6 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -232,26 +222,19 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreExportInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param output_config: Required. Specify data to be exported.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.OutputConfig`
-    :type output_config: Union[Dict, google.cloud.redis_v1.types.OutputConfig]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -260,7 +243,6 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -326,24 +308,17 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreFailoverInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param data_protection_mode: Optional. Available data protection modes that the user can choose. If it's
         unspecified, data protection mode will be LIMITED_DATA_LOSS by default.
-    :type data_protection_mode: google.cloud.redis_v1.gapic.enums.FailoverInstanceRequest.DataProtectionMode
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -352,7 +327,6 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -416,21 +390,15 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreGetInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -439,7 +407,6 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -503,26 +470,19 @@ class CloudMemorystoreImportOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreImportOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param input_config: Required. Specify data to be imported.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.InputConfig`
-    :type input_config: Union[Dict, google.cloud.redis_v1.types.InputConfig]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -531,7 +491,6 @@ class CloudMemorystoreImportOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -597,23 +556,17 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
         If it is specified as ``-`` (wildcard), then all regions available to the project are
         queried, and the results are aggregated.
-    :type location: str
     :param page_size: The maximum number of resources contained in the underlying API response. If page
         streaming is performed per- resource, this parameter does not affect the return value. If page
         streaming is performed per-page, this determines the maximum number of resources in a page.
-    :type page_size: int
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -622,7 +575,6 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -694,29 +646,20 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:CloudMemorystoreUpdateInstanceOperator`
 
-    :type update_mask: Union[Dict, google.cloud.redis_v1.types.FieldMask]
     :param instance: Required. Update description. Only fields specified in update_mask are updated.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.Instance`
-    :type instance: Union[Dict, google.cloud.redis_v1.types.Instance]
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: The logical name of the Redis instance in the customer project.
-    :type instance_id: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -725,7 +668,6 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -793,24 +735,16 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreScaleInstanceOperator`
 
     :param memory_size_gb: Redis memory size in GiB.
-    :type memory_size_gb: int
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: The logical name of the Redis instance in the customer project.
-    :type instance_id: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -819,7 +753,6 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -889,7 +822,6 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreCreateInstanceAndImportOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: Required. The logical name of the Redis instance in the customer project with the
         following restrictions:
 
@@ -898,30 +830,22 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         -  Must be between 1-40 characters.
         -  Must end with a number or a letter.
         -  Must be unique within the customer project / location
-    :type instance_id: str
     :param instance: Required. A Redis [Instance] resource
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.Instance`
-    :type instance: Union[Dict, google.cloud.redis_v1.types.Instance]
     :param input_config: Required. Specify data to be imported.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.InputConfig`
-    :type input_config: Union[Dict, google.cloud.redis_v1.types.InputConfig]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -930,7 +854,6 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1011,26 +934,19 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreExportAndDeleteInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Redis instance in the customer project.
-    :type instance: str
     :param output_config: Required. Specify data to be exported.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.redis_v1.types.OutputConfig`
-    :type output_config: Union[Dict, google.cloud.redis_v1.types.OutputConfig]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1039,7 +955,6 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1113,26 +1028,18 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreMemcachedApplyParametersOperator`
 
     :param node_ids: Nodes to which we should apply the instance-level parameter group.
-    :type node_ids: Sequence[str]
     :param apply_all: Whether to apply instance-level parameter group to all nodes. If set to true,
         will explicitly restrict users from specifying any nodes, and apply parameter group updates
         to all nodes within the instance.
-    :type apply_all: bool
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: The logical name of the Memcached instance in the customer project.
-    :type instance_id: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1203,7 +1110,6 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreMemcachedCreateInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: Required. The logical name of the Memcached instance in the customer project with the
         following restrictions:
 
@@ -1212,25 +1118,18 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         -  Must be between 1-40 characters.
         -  Must end with a number or a letter.
         -  Must be unique within the customer project / location
-    :type instance_id: str
     :param instance: Required. A Memcached [Instance] resource
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.Instance`
-    :type instance: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.Instance]
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the GCP connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
-    :type gcp_conn_id: str
     """
 
     template_fields: Sequence[str] = (
@@ -1290,22 +1189,15 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreMemcachedDeleteInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Memcached instance in the customer project.
-    :type instance: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the GCP connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
-    :type gcp_conn_id: str
     """
 
     template_fields: Sequence[str] = (
@@ -1360,21 +1252,15 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudMemorystoreMemcachedGetInstanceOperator`
 
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance: The logical name of the Memcached instance in the customer project.
-    :type instance: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud Platform.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1383,7 +1269,6 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1447,19 +1332,14 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
         If it is specified as ``-`` (wildcard), then all regions available to the project are
         queried, and the results are aggregated.
-    :type location: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1468,7 +1348,6 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1527,35 +1406,26 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         -  ``displayName``
 
         If a dict is provided, it must be of the same form as the protobuf message
-        :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.field_mask.FieldMas`
+        :class:`~google.protobuf.field_mask_pb2.FieldMask`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:CloudMemorystoreMemcachedUpdateInstanceOperator`
 
-    :type update_mask: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.field_mask.FieldMask]
     :param instance: Required. Update description. Only fields specified in update_mask are updated.
 
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.Instance`
-    :type instance: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.Instance]
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: The logical name of the Memcached instance in the customer project.
-    :type instance_id: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1564,7 +1434,6 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1583,7 +1452,7 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, cloud_memcache.field_mask.FieldMask],
+        update_mask: Union[Dict, FieldMask],
         instance: Union[Dict, cloud_memcache.Instance],
         location: Optional[str] = None,
         instance_id: Optional[str] = None,
@@ -1635,28 +1504,19 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
 
     :param update_mask: Required. Mask of fields to update.
         If a dict is provided, it must be of the same form as the protobuf message
-        :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.field_mask.FieldMask`
-    :type update_mask:
-        Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.field_mask.FieldMask]
+        :class:`~google.protobuf.field_mask_pb2.FieldMask`
     :param parameters: The parameters to apply to the instance.
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.MemcacheParameters`
-    :type parameters: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.MemcacheParameters]
     :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-    :type location: str
     :param instance_id: The logical name of the Memcached instance in the customer project.
-    :type instance_id: str
     :param project_id: Project ID of the project that contains the instance. If set
         to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
         retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
         ``retry`` is specified, the timeout applies to each individual attempt.
-    :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: Sequence[Tuple[str, str]]
     """
 
     template_fields: Sequence[str] = (
@@ -1675,7 +1535,7 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, cloud_memcache.field_mask.FieldMask],
+        update_mask: Union[Dict, FieldMask],
         parameters: Union[Dict, cloud_memcache.MemcacheParameters],
         location: str,
         instance_id: str,
