@@ -24,11 +24,106 @@ from googleapiclient.errors import HttpError
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datafusion import SUCCESS_STATES, DataFusionHook, PipelineStates
+from airflow.providers.google.cloud.links.base import BaseGoogleLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
+BASE_LINK = "https://console.cloud.google.com/data-fusion"
+DATAFUSION_INSTANCE_LINK = BASE_LINK + "/locations/{region}/instances/{instance_name}?project={project_id}"
+DATAFUSION_PIPELINES_LINK = "{uri}/cdap/ns/default/pipelines"
+DATAFUSION_PIPELINE_LINK = "{uri}/pipelines/ns/default/view/{pipeline_name}"
+
+
+class DataFusionPipelineLinkHelper:
+    """Helper class for Pipeline links"""
+
+    @staticmethod
+    def get_project_id(instance):
+        instance = instance["name"]
+        project_id = [x for x in instance.split("/") if x.startswith("airflow")][0]
+        return project_id
+
+
+class DataFusionInstanceLink(BaseGoogleLink):
+    """Helper class for constructing Data Fusion Instance link"""
+
+    name = "Data Fusion Instance"
+    key = "instance_conf"
+    format_str = DATAFUSION_INSTANCE_LINK
+
+    @staticmethod
+    def persist(
+        context: "Context",
+        task_instance: Union[
+            "CloudDataFusionRestartInstanceOperator",
+            "CloudDataFusionCreateInstanceOperator",
+            "CloudDataFusionUpdateInstanceOperator",
+            "CloudDataFusionGetInstanceOperator",
+        ],
+        project_id: str,
+    ):
+        task_instance.xcom_push(
+            context=context,
+            key=DataFusionInstanceLink.key,
+            value={
+                "region": task_instance.location,
+                "instance_name": task_instance.instance_name,
+                "project_id": project_id,
+            },
+        )
+
+
+class DataFusionPipelineLink(BaseGoogleLink):
+    """Helper class for constructing Data Fusion Pipeline link"""
+
+    name = "Data Fusion Pipeline"
+    key = "pipeline_conf"
+    format_str = DATAFUSION_PIPELINE_LINK
+
+    @staticmethod
+    def persist(
+        context: "Context",
+        task_instance: Union[
+            "CloudDataFusionCreatePipelineOperator",
+            "CloudDataFusionStartPipelineOperator",
+            "CloudDataFusionStopPipelineOperator",
+        ],
+        uri: str,
+    ):
+        task_instance.xcom_push(
+            context=context,
+            key=DataFusionPipelineLink.key,
+            value={
+                "uri": uri,
+                "pipeline_name": task_instance.pipeline_name,
+            },
+        )
+
+
+class DataFusionPipelinesLink(BaseGoogleLink):
+    """Helper class for constructing list of Data Fusion Pipelines link"""
+
+    name = "Data Fusion Pipelines"
+    key = "pipelines_conf"
+    format_str = DATAFUSION_PIPELINES_LINK
+
+    @staticmethod
+    def persist(
+        context: "Context",
+        task_instance: "CloudDataFusionListPipelinesOperator",
+        uri: str,
+    ):
+        task_instance.xcom_push(
+            context=context,
+            key=DataFusionPipelinesLink.key,
+            value={
+                "uri": uri,
+            },
+        )
+
+
 class CloudDataFusionRestartInstanceOperator(BaseOperator):
     """
     Restart a single Data Fusion instance.
@@ -39,19 +134,13 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionRestartInstanceOperator`
 
     :param instance_name: The name of the instance to restart.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
-    :type project_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -60,13 +149,13 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
         "instance_name",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionInstanceLink(),)
 
     def __init__(
         self,
@@ -102,9 +191,12 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
             location=self.location,
             project_id=self.project_id,
         )
-        hook.wait_for_operation(operation)
+        instance = hook.wait_for_operation(operation)
         self.log.info("Instance %s restarted successfully", self.instance_name)
 
+        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
+        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+
 
 class CloudDataFusionDeleteInstanceOperator(BaseOperator):
     """
@@ -115,19 +207,13 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionDeleteInstanceOperator`
 
     :param instance_name: The name of the instance to restart.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
-    :type project_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -136,7 +222,6 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -191,22 +276,15 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionCreateInstanceOperator`
 
     :param instance_name: The name of the instance to create.
-    :type instance_name: str
     :param instance: An instance of Instance.
         https://cloud.google.com/data-fusion/docs/reference/rest/v1beta1/projects.locations.instances#Instance
-    :type instance: Dict[str, Any]
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
-    :type project_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -215,7 +293,6 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -223,6 +300,7 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
         "instance",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionInstanceLink(),)
 
     def __init__(
         self,
@@ -279,6 +357,9 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
                 instance = hook.get_instance(
                     instance_name=self.instance_name, location=self.location, project_id=self.project_id
                 )
+
+        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
+        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
         return instance
 
 
@@ -291,29 +372,21 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionUpdateInstanceOperator`
 
     :param instance_name: The name of the instance to create.
-    :type instance_name: str
     :param instance: An instance of Instance.
         https://cloud.google.com/data-fusion/docs/reference/rest/v1beta1/projects.locations.instances#Instance
-    :type instance: Dict[str, Any]
     :param update_mask: Field mask is used to specify the fields that the update will overwrite
         in an instance resource. The fields specified in the updateMask are relative to the resource,
         not the full request. A field will be overwritten if it is in the mask. If the user does not
         provide a mask, all the supported fields (labels and options currently) will be overwritten.
         A comma-separated list of fully qualified names of fields. Example: "user.displayName,photo".
         https://developers.google.com/protocol-buffers/docs/reference/google.protobuf?_ga=2.205612571.-968688242.1573564810#google.protobuf.FieldMask
-    :type update_mask: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
-    :type project_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -322,7 +395,6 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -330,6 +402,7 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         "instance",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionInstanceLink(),)
 
     def __init__(
         self,
@@ -371,9 +444,12 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
             location=self.location,
             project_id=self.project_id,
         )
-        hook.wait_for_operation(operation)
+        instance = hook.wait_for_operation(operation)
         self.log.info("Instance %s updated successfully", self.instance_name)
 
+        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
+        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+
 
 class CloudDataFusionGetInstanceOperator(BaseOperator):
     """
@@ -384,19 +460,13 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionGetInstanceOperator`
 
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
-    :type project_id: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -405,13 +475,13 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
         "instance_name",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionInstanceLink(),)
 
     def __init__(
         self,
@@ -447,6 +517,9 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
             location=self.location,
             project_id=self.project_id,
         )
+
+        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
+        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
         return instance
 
 
@@ -459,26 +532,18 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionCreatePipelineOperator`
 
     :param pipeline_name: Your pipeline name.
-    :type pipeline_name: str
     :param pipeline: The pipeline definition. For more information check:
         https://docs.cdap.io/cdap/current/en/developer-manual/pipelines/developing-pipelines.html#pipeline-configuration-file-format
-    :type pipeline: Dict[str, Any]
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param namespace: If your pipeline belongs to a Basic edition instance, the namespace ID
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
-    :type namespace: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -487,7 +552,6 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -495,6 +559,7 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         "pipeline_name",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionPipelineLink(),)
 
     def __init__(
         self,
@@ -543,6 +608,8 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
             instance_url=api_url,
             namespace=self.namespace,
         )
+
+        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
         self.log.info("Pipeline created")
 
 
@@ -555,25 +622,17 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionDeletePipelineOperator`
 
     :param pipeline_name: Your pipeline name.
-    :type pipeline_name: str
     :param version_id: Version of pipeline to delete
-    :type version_id: Optional[str]
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param namespace: If your pipeline belongs to a Basic edition instance, the namespace ID
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
-    :type namespace: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -582,7 +641,6 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -652,25 +710,17 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
 
 
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param artifact_version: Artifact version to filter instances
-    :type artifact_version: Optional[str]
     :param artifact_name: Artifact name to filter instances
-    :type artifact_name: Optional[str]
     :param namespace: If your pipeline belongs to a Basic edition instance, the namespace ID
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
-    :type namespace: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -679,7 +729,6 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -688,6 +737,7 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
         "artifact_version",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionPipelinesLink(),)
 
     def __init__(
         self,
@@ -737,6 +787,8 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
             artifact_name=self.artifact_name,
         )
         self.log.info("%s", pipelines)
+
+        DataFusionPipelinesLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
         return pipelines
 
 
@@ -749,31 +801,21 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionStartPipelineOperator`
 
     :param pipeline_name: Your pipeline name.
-    :type pipeline_name: str
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param success_states: If provided the operator will wait for pipeline to be in one of
         the provided states.
-    :type success_states: List[str]
     :param pipeline_timeout: How long (in seconds) operator should wait for the pipeline to be in one of
         ``success_states``. Works only if ``success_states`` are provided.
-    :type pipeline_timeout: int
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param runtime_args: Optional runtime args to be passed to the pipeline
-    :type runtime_args: dict
     :param namespace: If your pipeline belongs to a Basic edition instance, the namespace ID
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
-    :type namespace: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -782,11 +824,9 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param asynchronous: Flag to return after submitting the pipeline Id to the Data Fusion API.
         This is useful for submitting long running pipelines and
         waiting on them asynchronously using the CloudDataFusionPipelineStateSensor
-    :type asynchronous: bool
     """
 
     template_fields: Sequence[str] = (
@@ -795,6 +835,7 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         "runtime_args",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionPipelineLink(),)
 
     def __init__(
         self,
@@ -855,6 +896,8 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         )
         self.log.info("Pipeline %s submitted successfully.", pipeline_id)
 
+        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
+
         if not self.asynchronous:
             self.log.info("Waiting when pipeline %s will be in one of the success states", pipeline_id)
             hook.wait_for_pipeline_state(
@@ -878,23 +921,16 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionStopPipelineOperator`
 
     :param pipeline_name: Your pipeline name.
-    :type pipeline_name: str
     :param instance_name: The name of the instance.
-    :type instance_name: str
     :param location: The Cloud Data Fusion location in which to handle the request.
-    :type location: str
     :param namespace: If your pipeline belongs to a Basic edition instance, the namespace ID
         is always default. If your pipeline belongs to an Enterprise edition instance, you
         can create a namespace.
-    :type namespace: str
     :param api_version: The version of the api that will be requested for example 'v3'.
-    :type api_version: str
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -903,7 +939,6 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -911,6 +946,7 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         "pipeline_name",
         "impersonation_chain",
     )
+    operator_extra_links = (DataFusionPipelineLink(),)
 
     def __init__(
         self,
@@ -944,16 +980,18 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
-        self.log.info("Starting Data Fusion pipeline: %s", self.pipeline_name)
+        self.log.info("Data Fusion pipeline: %s is going to be stopped", self.pipeline_name)
         instance = hook.get_instance(
             instance_name=self.instance_name,
             location=self.location,
             project_id=self.project_id,
         )
         api_url = instance["apiEndpoint"]
+
+        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
         hook.stop_pipeline(
             pipeline_name=self.pipeline_name,
             instance_url=api_url,
             namespace=self.namespace,
         )
-        self.log.info("Pipeline started")
+        self.log.info("Pipeline stopped")
