@@ -50,37 +50,27 @@ class CassandraToGCSOperator(BaseOperator):
     Note: Arrays of arrays are not supported.
 
     :param cql: The CQL to execute on the Cassandra table.
-    :type cql: str
     :param bucket: The bucket to upload to.
-    :type bucket: str
     :param filename: The filename to use as the object name when uploading
         to Google Cloud Storage. A {} should be specified in the filename
         to allow the operator to inject file numbers in cases where the
         file is split due to size.
-    :type filename: str
     :param schema_filename: If set, the filename to use as the object name
         when uploading a .json file containing the BigQuery schema fields
         for the table that was dumped from MySQL.
-    :type schema_filename: str
     :param approx_max_file_size_bytes: This operator supports the ability
         to split large table dumps into multiple files (see notes in the
         filename param docs above). This param allows developers to specify the
         file size of the splits. Check https://cloud.google.com/storage/quotas
         to see the maximum allowed file size for a single object.
-    :type approx_max_file_size_bytes: long
     :param cassandra_conn_id: Reference to a specific Cassandra hook.
-    :type cassandra_conn_id: str
     :param gzip: Option to compress file for upload
-    :type gzip: bool
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param google_cloud_storage_conn_id: (Deprecated) The connection ID used to connect to Google Cloud.
         This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
-    :type google_cloud_storage_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -89,11 +79,9 @@ class CassandraToGCSOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param query_timeout: (Optional) The amount of time, in seconds, used to execute the Cassandra query.
         If not set, the timeout value will be set in Session.execute() by Cassandra driver.
         If set to None, there is no timeout.
-    :type query_timeout: float | None
     """
 
     template_fields: Sequence[str] = (
