@@ -41,28 +41,21 @@ class GCSToLocalFilesystemOperator(BaseOperator):
 
     :param bucket: The Google Cloud Storage bucket where the object is.
         Must not contain 'gs://' prefix. (templated)
-    :type bucket: str
     :param object_name: The name of the object to download in the Google cloud
         storage bucket. (templated)
-    :type object_name: str
     :param filename: The file path, including filename,  on the local file system (where the
         operator is being executed) that the file should be downloaded to. (templated)
         If no filename passed, the downloaded data will not be stored on the local file
         system.
-    :type filename: str
     :param store_to_xcom_key: If this param is set, the operator will push
         the contents of the downloaded file to XCom with the key set in this
         parameter. If not set, the downloaded data will not be pushed to XCom. (templated)
-    :type store_to_xcom_key: str
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param google_cloud_storage_conn_id: (Deprecated) The connection ID used to connect to Google Cloud
         This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
-    :type google_cloud_storage_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -71,7 +64,8 @@ class GCSToLocalFilesystemOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
+    :param file_encoding: Optional encoding used to decode file_bytes into a serializable
+        string that is suitable for storing to XCom. (templated).
     """
 
     template_fields: Sequence[str] = (
@@ -80,6 +74,7 @@ class GCSToLocalFilesystemOperator(BaseOperator):
         'filename',
         'store_to_xcom_key',
         'impersonation_chain',
+        'file_encoding',
     )
     ui_color = '#f0eee4'
 
@@ -94,6 +89,7 @@ class GCSToLocalFilesystemOperator(BaseOperator):
         google_cloud_storage_conn_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        file_encoding: str = 'utf-8',
         **kwargs,
     ) -> None:
         # To preserve backward compatibility
@@ -126,6 +122,7 @@ class GCSToLocalFilesystemOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
+        self.file_encoding = file_encoding
 
     def execute(self, context: 'Context'):
         self.log.info('Executing download: %s, %s, %s', self.bucket, self.object_name, self.filename)
@@ -139,7 +136,7 @@ class GCSToLocalFilesystemOperator(BaseOperator):
             file_size = hook.get_size(bucket_name=self.bucket, object_name=self.object_name)
             if file_size < MAX_XCOM_SIZE:
                 file_bytes = hook.download(bucket_name=self.bucket, object_name=self.object_name)
-                context['ti'].xcom_push(key=self.store_to_xcom_key, value=str(file_bytes))
+                context['ti'].xcom_push(key=self.store_to_xcom_key, value=str(file_bytes, self.file_encoding))
             else:
                 raise AirflowException('The size of the downloaded file is too large to push to XCom!')
         else:
