@@ -28,7 +28,6 @@ import pendulum
 
 from airflow.providers.google.cloud.transfers.sql_to_gcs import BaseSQLToGCSOperator
 from airflow.providers.postgres.hooks.postgres import PostgresHook
-from airflow.utils.decorators import apply_defaults
 
 
 class _PostgresServerSideCursorDecorator:
@@ -60,7 +59,8 @@ class _PostgresServerSideCursorDecorator:
         """Fetch first row to initialize cursor description when using server side cursor."""
         if not self.initialized:
             element = self.cursor.fetchone()
-            self.rows.append(element)
+            if element is not None:
+                self.rows.append(element)
             self.initialized = True
         return self.cursor.description
 
@@ -70,12 +70,9 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
     Copy data from Postgres to Google Cloud Storage in JSON or CSV format.
 
     :param postgres_conn_id: Reference to a specific Postgres hook.
-    :type postgres_conn_id: str
     :param use_server_side_cursor: If server-side cursor should be used for querying postgres.
         For detailed info, check https://www.psycopg.org/docs/usage.html#server-side-cursors
-    :type use_server_side_cursor: bool
     :param cursor_itersize: How many records are fetched at a time in case of server-side cursor.
-    :type cursor_itersize: int
     """
 
     ui_color = '#a0e08c'
@@ -97,7 +94,6 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
         1700: 'FLOAT',
     }
 
-    @apply_defaults
     def __init__(
         self,
         *,
